*set directory: enter pathname to directory where MxFLS files have been saved
cd 




***THE FOLLOWING STEPS RESHAPE AND MERGE ALL NEEDED DATA 


*create a file with household size, needed for poverty index
use "hh02dta_all\hh02dta_bc\c_ls.dta", clear
gen HHsize=1
collapse (sum) HHsize, by(folio)
sort folio
save .\HHsize.dta, replace

*create a file with information about household head, needed for poverty index
use "hh02dta_all\hh02dta_bc\c_ls.dta", clear
*keep household heads
keep if ls05_1==1
gen HHheadlowed=0
replace HHheadlowed=1 if (ls14==1 | ls14==2) | (ls14==3 & ls15_1<=5)
sort folio ls
*merge to get literacy info
merge folio ls using "hh02dta_all\hh02dta_b3a\iiia_ed.dta"
drop if _merge==2
gen HHheadillit=0
replace HHheadillit=1 if ed02==3
drop _merge
*merge to get wage info
sort folio ls
merge folio ls using "hh02dta_all\hh02dta_b3a\iiia_tb.dta"
drop if _merge==2
gen HHheadwg=tb35a_2/20 if tb02_1==1
keep HHheadlowed HHheadillit HHheadwg folio
sort folio
save .\HHhead.dta, replace

*merge all data to household roster
use "hh02dta_all\hh02dta_bc\c_ls.dta", clear

*merge in weights
sort folio
merge folio using "hh02dta_all\Weights\hh02w_bc.dta"
tab _merge
drop _merge

*merge in geographic identifiers
sort folio
merge folio using "hh02dta_all\hh02dta_bc\c_portad.dta"
tab _merge
drop if _merge==2
drop _merge

*merge in employment information 
sort folio ls
merge folio ls using "hh02dta_all\hh02dta_b3a\iiia_tb.dta"
tab _merge
drop if _merge==2
drop _merge

*merge in indigenous identity information
sort folio ls
merge folio ls using "hh02dta_all\hh02dta_b3a\iiia_ed.dta"
tab _merge
drop if _merge==2
drop _merge

*merge in household characteristics, needed for poverty index
sort folio
merge folio using ".\HHsize.dta"
tab _merge
drop if _merge==2
drop _merge

sort folio
merge folio using ".\HHhead.dta"
tab _merge
drop if _merge==2
drop _merge

sort folio
merge folio using "hh02dta_all\hh02dta_bc\c_cv.dta"
tab _merge
drop if _merge==2
drop _merge

sort folio
merge folio using "hh02dta_all\hh02dta_bc\c_cvo.dta"
tab _merge
drop if _merge==2
drop _merge

*generate id to link to wave 2 migration file
gen str8 var1=string(folio, "%08.0f")
gen str2 var2=string(ls,"%02.0f")
gen pid_link=var1+var2

*merge to wave 2 migration file
sort pid_link
merge pid_link using ".hh02dta_all\migus.dta"
tab _merge
drop _merge





****THE FOLLOWING STEPS CREATE AND/OR LABEL THE VARIABLES IN THE ANALYSIS

*Gender
rename  ls04 sex
recode sex 1=0 3=1 
label val sex sex
label def sex 0 "0 Male" 1 "1 Female"

gen male=0
replace male=1 if sex==0

*Education
rename ls14 educ_lev
rename ls15 educ_grd
gen edcat=0 if educ_lev==1 
replace edcat=1 if educ_lev==2 | (educ_lev==3 & educ_grd<=5) 
replace edcat=2 if educ_lev==3 & educ_grd>=6 & educ_grd!=. 
replace edcat=3 if educ_lev==4 | educ_lev==5
replace edcat=4 if educ_lev==6 | educ_lev==7 | educ_lev==8
replace edcat=5 if educ_lev>=9 & educ_lev!=. & educ_lev!=98
label var edcat "Level of education"
label val edcat edcat
label def edcat 0 "0 None" 1 "1 <Prim" 2 "2 Prim" 3 "3 JrHS" 4 "4 HS" 5 "5 Coll" 

*Occupational role
gen worker= 0 if tb32p==1 | tb32p==4
replace worker = 1 if tb32p==2 | tb32p==7
replace worker = 2 if tb32p==6
replace worker = 3 if tb32p== 3
replace worker = 4 if tb32p== 5
label def worker 0 "0 Peas/peon" 1 "1 Non-renum emp" 2 "2 Self-emp" 3 "3 Emp" 4 "4 Boss"
label val worker worker
label var worker "Occupational role"

*Household poverty
gen nowater=0
replace nowater=1 if cv08_1==4 | cv08_1==5 | cv08_1==6
gen crowded=0
replace crowded=1 if HHsize/cv07>2
gen notoil=0
replace notoil=1 if cv16!=1 & (cv17_1c==3 | cv17_1d==4 | cv17_1e==5 | cv17_1f==6) 
gen noelec=0
replace noelec=1 if cvo04==3
gen dirtfloor=0
replace dirtfloor=1 if cvo05_1==3
gen zona=3
replace zona=1 if edo==02 | edo==03 | edo==09 | (edo==08 & (mpio==028 | mpio==037 | mpio==053)) | (edo==12 & mpio==001) | (edo==15 & (mpio==013 | mpio==020 | mpio==024 | mpio==121 | mpio==033 | mpio==057 | mpio==104 | mpio==109)) | (edo==26 & (mpio==002 | mpio==019 | mpio==039 | mpio==043 | mpio==070 | mpio==048 | mpio==055 | mpio==059)) | (edo==28 & (mpio==007 | mpio==014 | mpio==015 | mpio==022 | mpio==024 | mpio==025 | mpio==027 | mpio==032 | mpio==033 | mpio==035 | mpio==040)) | (edo==30 & (mpio==204 | mpio==039 | mpio==048 | mpio==061 | mpio==082 | mpio==108 | mpio==111 | mpio==206))
replace zona=2 if (edo==30 & (mpio==040 | mpio==131 | mpio==189)) | (edo==14 & (mpio==039 | mpio==070 | mpio==097 | mpio==098 | mpio==101 | mpio==120)) | (edo==19 & (mpio==006 | mpio==019 | mpio==021 | mpio==026 | mpio==039 | mpio==046 | mpio==048)) | (edo==28 & (mpio==002 | mpio==003 | mpio==004 | mpio==009 | mpio==011 | mpio==012 | mpio==021 | mpio==028 | mpio==029 | mpio==038 | mpio==043)) | (edo==26 & (mpio==004 | mpio==007 | mpio==012 | mpio==071 | mpio==016 | mpio==017 | mpio==018 | mpio==020 | mpio==021 | mpio==022 | mpio==025 | mpio==026 | mpio==029 | mpio==030 | mpio==033 | mpio==035 | mpio==036 | mpio==042 | mpio==045 | mpio==046 | mpio==047 | mpio==072 | mpio==056 | mpio==058 | mpio==060 | mpio==062 | mpio==064 | mpio==065))
label var zona "Minimum wage area"
label val zona zona
label define zona 1 "Zone 1" 2 "Zone 2" 3 "Zone 3"
gen HHheadlowwg=0
replace HHheadlowwg=1 if (HHheadwg<=84.3 & zona==1) | (HHheadwg<=80.2 & zona==2) | (HHheadwg<=76.6 & zona==3)
recode nowater .=0
recode noelec .=0
recode notoil .=0
recode dirtfloor .=0
recode HHheadlowwg .=0
recode HHheadlowed .=0
recode HHheadill .=0
recode crowded .=0
gen HHmargcat= nowater + notoil + noelec + dirtfloor + HHheadlowed + HHheadill + crowded + HHheadlowwg
label var HHmarg "Household marginality" 
tab HHmarg
recode HHmarg 5/8=4

*Indigenous identity
gen indig=0
replace indig=1 if ed03==1
replace indig=2 if ed04==1
label var indig "Indigenous id"
label val indig indig
label def indig 0 "0 Not indig" 1 "1 Indig id" 2 "2 Indig lang"

*Regions
gen region=0 if edo==5 | edo==10 | edo==19 
*Center-Northeast Region: Entities 5, 10 and 19. Coahuila, Durango, Nuevo Leon 
replace region=1 if edo==3 | edo==25 | edo==26
*Northwest Region: Entities 3, 25, 26. BCS, Sinaloa, Sonora 
replace region=2 if edo==11 | edo==14 | edo==16 
*Central Region-West: Entities 11, 14 and 16. Guanajuato, Jalisco, Michoacan 
replace region=3 if edo==9 | edo==15 | edo==17 | edo==21
*Central Country Region: Entities 9, 15, 17, 21. DF, Mexico, Morelos, Puebla 
replace region=4 if edo==20 | edo==30 | edo==31
*South-Southeast Region: Entities 20, 30, 31. Oaxaca, Veracruz, Yucatan 
label val region region
label def region 0 "0 Center-NE" 1 "1 NW" 2 "2 Central-West" 3 "3 Central" 4 "4 S-Se"

*Urbanization
*Estrato=1 Households located in localities with more than 100,000 inhabitants.
*Estrato=2  Households located in localities with populations between 15,000 and 100,000.
*Estrato=3    Households located in towns with a population between 2,500 and 15,000.
*Estrato=4   Households located in areas with less than 2,500 inhabitants.
label val estrato estrato
label def estrato 1 "1 >100,000" 2 "2 15,000-99,999" 3 "3 2,500-14,999" 4 "<2,500"

*adult
gen adult=0
replace adult=1 if ls02_2>14 & ls02_2!=.




****THE FOLLOWING STEPS PRODUCE THE RESULTS PRESENTED IN TABLE 1

svyset [pweight=factor_c]

*Analysis 
tab migus sex if adult==1, col
svy, subpop(adult): mean migus, over(sex)
svy, subpop(adult): logit migus male, or

bysort edcat: tab migus sex if adult==1, col
svy, subpop(adult): mean migus, over (sex edcat)
lincom [migus]_subpop_1 - [migus]_subpop_7
lincom [migus]_subpop_2 - [migus]_subpop_8
lincom [migus]_subpop_3 - [migus]_subpop_9
lincom [migus]_subpop_4 - [migus]_subpop_10
lincom [migus]_subpop_5 - [migus]_subpop_11
lincom [migus]_subpop_6 - [migus]_subpop_12
svy, subpop(adult): logit migus i.edcat i.edcat#male, or
test _b[0.edcat#1.male] =  _b[5.edcat#1.male]
test _b[0.edcat#1.male] = _b[1.edcat#1.male] = _b[2.edcat#1.male] = _b[3.edcat#1.male] = _b[4.edcat#1.male] = _b[5.edcat#1.male]

bysort worker: tab migus sex if adult==1, col 
svy, subpop(adult): mean migus, over (sex worker)
lincom [migus]_subpop_1 - [migus]_subpop_6
lincom [migus]_subpop_2 - [migus]_subpop_7
lincom [migus]_subpop_3 - [migus]_subpop_8
lincom [migus]_subpop_4 - [migus]_subpop_9
lincom [migus]_subpop_5 - [migus]_subpop_10
svy, subpop(adult): logit migus i.worker i.worker#male, or
test _b[0.worker#1.male] = _b[4.worker#1.male]
test _b[0.worker#1.male] = _b[1.worker#1.male] = _b[2.worker#1.male] = _b[3.worker#1.male] = _b[4.worker#1.male] 

bysort HHmargcat: tab migus sex if adult==1, col 
svy, subpop(adult): mean migus, over (sex HHmargcat)
lincom [migus]_subpop_1 - [migus]_subpop_6
lincom [migus]_subpop_2 - [migus]_subpop_7
lincom [migus]_subpop_3 - [migus]_subpop_8
lincom [migus]_subpop_4 - [migus]_subpop_9
lincom [migus]_subpop_5 - [migus]_subpop_10
svy, subpop(adult): logit migus i.HHmargcat i.HHmargcat#male, or
test _b[0.HHmargcat#1.male] = _b[4.HHmargcat#1.male]
test _b[0.HHmargcat#1.male] = _b[1.HHmargcat#1.male] = _b[2.HHmargcat#1.male] = _b[3.HHmargcat#1.male] = _b[4.HHmargcat#1.male]  

bysort indig: tab migus sex if adult==1, col chi2
svy, subpop(adult): mean migus, over (sex indig)
lincom [migus]_subpop_1 - [migus]_subpop_4
lincom [migus]_subpop_2 - [migus]_subpop_5
lincom [migus]_subpop_3 - [migus]_subpop_6
svy, subpop(adult): logit migus i.indig i.indig#male, or
test _b[0.indig#1.male] = _b[2.indig#1.male]
test _b[0.indig#1.male] = _b[1.indig#1.male] = _b[2.indig#1.male]

bysort region: tab migus sex if adult==1, col chi2
svy, subpop(adult): mean migus, over (sex region)
lincom [migus]_subpop_1 - [migus]_subpop_6
lincom [migus]_subpop_2 - [migus]_subpop_7
lincom [migus]_subpop_3 - [migus]_subpop_8
lincom [migus]_subpop_4 - [migus]_subpop_9
lincom [migus]_subpop_5 - [migus]_subpop_10
svy, subpop(adult): logit migus i.region i.region#male, or
test _b[0.region#1.male] = _b[4.region#1.male]
test _b[0.region#1.male] = _b[1.region#1.male] = _b[2.region#1.male] = _b[3.region#1.male] = _b[4.region#1.male] 

bysort estrato: tab migus sex if adult==1, col chi2
svy, subpop(adult): mean migus, over (sex estrato)
lincom [migus]_subpop_1 - [migus]_subpop_5
lincom [migus]_subpop_2 - [migus]_subpop_6
lincom [migus]_subpop_3 - [migus]_subpop_7
lincom [migus]_subpop_4 - [migus]_subpop_8
svy, subpop(adult): logit migus i.estrato i.estrato#male, or
test _b[1.estrato#1.male] = _b[4.estrato#1.male]
test _b[1.estrato#1.male] = _b[2.estrato#1.male] = _b[3.estrato#1.male] = _b[4.estrato#1.male]

